@@ -297,7 +297,7 @@ def create_if_not_exist(file_name: str, path: str = None) -> str:
     file_name = f'{path}{file_name}'
 
     try:
-        print(f'{path}{file_name}')
+        logger.debug(f"Creating file {file_name}")
         open(file_name, 'r').close()
     except IOError as e:
         open(file_name, 'w').close()
